Module atomic

Module atomic 

The AtomicStorage trait and associated components

Structs

AtomicBool
A boolean type which can be safely shared between threads.
AtomicI8
An integer type which can be safely shared between threads.
AtomicI16
An integer type which can be safely shared between threads.
AtomicI32
An integer type which can be safely shared between threads.
AtomicI64
An integer type which can be safely shared between threads.
AtomicIsize
An integer type which can be safely shared between threads.
AtomicPtr
A raw pointer type which can be safely shared between threads.
AtomicU8
An integer type which can be safely shared between threads.
AtomicU16
An integer type which can be safely shared between threads.
AtomicU32
An integer type which can be safely shared between threads.
AtomicU64
An integer type which can be safely shared between threads.
AtomicUnit
A () type which can be safely shared between threads.
AtomicUsize
An integer type which can be safely shared between threads.

Enums

Ordering
Atomic memory orderings

Traits

AtomicStorage
An atomic type which can be safely shared between threads. Drop::drop behavior is somewhat unintuitive, so types are advised to avoid implementing it. See crate::cell::AtomicCell for more info.
AtomicStorageBase
An abstraction to deal with the constness of AtomicStorage
FromInner
A const wrapper for into_inner.

Functions

compare_exchange
A wrapper around AtomicStorage::compare_exchange and AtomicStorage::compare_exchange_weak