FromInner

Trait FromInner 

pub trait FromInner<A> {
    // Required method
    fn from_inner(a: A) -> Self;
}
A const wrapper for into_inner.

Required Methods

fn from_inner(a: A) -> Self

Consumes the atomic and returns the contained value.

This is safe because passing self by value guarantees that no other threads are concurrently accessing the atomic data.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<U, A: AtomicStorage<Underlying = U>> FromInner<A> for U