The AtomicStorage trait and associated components
Structs
- Atomic
Bool - A boolean type which can be safely shared between threads.
- Atomic
I8 - An integer type which can be safely shared between threads.
- Atomic
I16 - An integer type which can be safely shared between threads.
- Atomic
I32 - An integer type which can be safely shared between threads.
- Atomic
I64 - An integer type which can be safely shared between threads.
- Atomic
Isize - An integer type which can be safely shared between threads.
- Atomic
Ptr - A raw pointer type which can be safely shared between threads.
- Atomic
U8 - An integer type which can be safely shared between threads.
- Atomic
U16 - An integer type which can be safely shared between threads.
- Atomic
U32 - An integer type which can be safely shared between threads.
- Atomic
U64 - An integer type which can be safely shared between threads.
- Atomic
Unit - A
()type which can be safely shared between threads. - Atomic
Usize - An integer type which can be safely shared between threads.
Enums
- Ordering
- Atomic memory orderings
Traits
- Atomic
Storage - An atomic type which can be safely shared between threads.
Drop::dropbehavior is somewhat unintuitive, so types are advised to avoid implementing it. Seecrate::cell::AtomicCellfor more info. - Atomic
Storage Base - An abstraction to deal with the
constness ofAtomicStorage - From
Inner - A const wrapper for
into_inner.
Functions
- compare_
exchange - A wrapper around
AtomicStorage::compare_exchangeandAtomicStorage::compare_exchange_weak